@@ -4,10 +4,12 @@ Operations on strings:
 - transform strings with transformation codes
 """
 
+import unicodedata
+
 from .char_player import distanceBetweenChars
 
 
-#### Ngrams
+#### N-GRAMS
 
 def getNgrams (sWord, n=2):
     "return a list of Ngrams strings"
@@ -15,6 +17,50 @@ def getNgrams (sWord, n=2):
 
 
 
+#### WORD NORMALIZATION
+
+_xTransCharsForSpelling = str.maketrans({
+    'ſ': 's',  'ﬃ': 'ffi',  'ﬄ': 'ffl',  'ﬀ': 'ff',  'ﬅ': 'ft',  'ﬁ': 'fi',  'ﬂ': 'fl',  'ﬆ': 'st'
+})
+
+def spellingNormalization (sWord):
+    "nomalization NFC and removing ligatures"
+    return unicodedata.normalize("NFC", sWord.translate(_xTransCharsForSpelling))
+
+
+_xTransCharsForSimplification = str.maketrans({
+    'à': 'a',  'é': 'é',  'î': 'i',  'ô': 'o',  'û': 'u',  'ÿ': 'y',
+    'â': 'a',  'è': 'é',  'ï': 'i',  'ö': 'o',  'ù': 'u',  'ŷ': 'y',
+    'ä': 'a',  'ê': 'é',  'í': 'i',  'ó': 'o',  'ü': 'u',  'ý': 'y',
+    'á': 'a',  'ë': 'é',  'ì': 'i',  'ò': 'o',  'ú': 'u',  'ỳ': 'y',
+    'ā': 'a',  'ē': 'é',  'ī': 'i',  'ō': 'o',  'ū': 'u',  'ȳ': 'y',
+    'ç': 'c',  'ñ': 'n',
+    'œ': 'oe',  'æ': 'ae',
+    'ſ': 's',  'ﬃ': 'ffi',  'ﬄ': 'ffl',  'ﬀ': 'ff',  'ﬅ': 'ft',  'ﬁ': 'fi',  'ﬂ': 'fl',  'ﬆ': 'st',
+    "⁰": "0", "¹": "1", "²": "2", "³": "3", "⁴": "4", "⁵": "5", "⁶": "6", "⁷": "7", "⁸": "8", "⁹": "9",
+    "₀": "0", "₁": "1", "₂": "2", "₃": "3", "₄": "4", "₅": "5", "₆": "6", "₇": "7", "₈": "8", "₉": "9"
+})
+
+def simplifyWord (sWord):
+    "word simplication before calculating distance between words"
+    sWord = sWord.lower().translate(_xTransCharsForSimplification)
+    sNewWord = ""
+    for i, c in enumerate(sWord, 1):
+        if c != sWord[i:i+1] or (c == 'e' and sWord[i:i+2] != "ee"):  # exception for <e> to avoid confusion between crée / créai
+            sNewWord += c
+    return sNewWord.replace("eau", "o").replace("au", "o").replace("ai", "éi").replace("ei", "é").replace("ph", "f")
+
+
+_xTransNumbersToExponent = str.maketrans({
+    "0": "⁰", "1": "¹", "2": "²", "3": "³", "4": "⁴", "5": "⁵", "6": "⁶", "7": "⁷", "8": "⁸", "9": "⁹"
+})
+
+def numbersToExponent (sWord):
+    "convert numeral chars to exponant chars"
+    return sWord.translate(_xTransNumbersToExponent)
+
+
+
 #### DISTANCE CALCULATIONS
 
 def longestCommonSubstring (s1, s2):
